@@ -1,10 +1,11 @@
 package Lingua::Zompist::Verdurian;
+# vim:set tw=72 sw=2:
 
 use 5.005;
 use strict;
 
 require Exporter;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
+use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $keep_accents);
 @ISA = qw(Exporter);
 
 # Items to export into callers namespace by default. Note: do not export
@@ -32,7 +33,11 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
 @EXPORT = qw(
 	
 );
-$VERSION = '0.90';
+$VERSION = '0.91';
+
+# Keep accents on words by default, even if the accented syllable would
+# be stressed anyway due to its position?
+$keep_accents = 1;
 
 my %verb = (demeric => \&demeric,
             scrifel => \&scrifel,
@@ -499,7 +504,9 @@ sub noun {
   } elsif($stem =~ s/iy$//) {
     $table = [ map "$stem$_", qw( iy ii iim in i i iom iuin ) ];
   } elsif($stem =~ s/y$//) {
-    $table = [ map "$stem$_", qw( y ii iim in i  iom uin ) ];
+    $table = [ map "$stem$_", $keep_accents
+                              ? qw( y i im in   om uin )
+                              : qw( y ii iim in i  iom uin ) ];
   } elsif($stem =~ s/y$//) {
     $table = [ map "$stem$_", qw( y ii im n  u om uin ) ];
   } elsif($type eq 'masc' && $stem =~ s/a$//) {
@@ -513,15 +520,23 @@ sub noun {
   } elsif($type eq 'fem' && $stem =~ s/$//) {
     $table = [ map "$stem$_", qw(    n  i m n ) ];
   } elsif($stem =~ s/$//) {
-    $table = [ map "$stem$_", qw(  ei m n oi o m oin ) ];
+    $table = [ map "$stem$_", $keep_accents
+                              ? qw(  i m n i o m in )
+                              : qw(  ei m n oi o m oin ) ];
   } elsif($stem =~ s/$//) {
-    $table = [ map "$stem$_", qw(  ui m n  u m uin ) ];
+    $table = [ map "$stem$_", $keep_accents
+                              ? qw(  i m n  u m in )
+                              : qw(  ui m n  u m uin ) ];
   } elsif($type eq 'masc' && $stem =~ s/$//) {
-    $table = [ map "$stem$_", qw(  ei  n ai a m ain ) ];
+    $table = [ map "$stem$_", $keep_accents
+                              ? qw(  i  n i a m in )
+                              : qw(  ei  n ai a m ain ) ];
   } elsif($stem =~ s/$//) {
     $table = [ map "$stem$_", qw(    n  i m n ) ];
   } elsif($stem =~ s/$//) {
-    $table = [ map "$stem$_", qw(  ei  n  i m n ) ];
+    $table = [ map "$stem$_", $keep_accents
+                              ? qw(  i  n  i m n )
+                              : qw(  ei  n  i m n ) ];
   } else {
     return;
   }
@@ -562,9 +577,9 @@ sub noun {
     s/^dushi$c/dushis/o ||
     s/^dha$c/dhas/o ||
     s/^dhie$c/dhies/o ||
-    s/^ecelg$/ecelozhi/ ||
+    s/^ecelg$/ecelzhi/ ||
     s/^ecel$g/ecelzh/o ||
-    s/^etalg$/etalozhi/ ||
+    s/^etalg$/etalzhi/ ||
     s/^etal$g/etalzh/o ||
     s/^feri$ca/feris/o ||
     s/^fifachi$c/fifachis/o ||
@@ -610,9 +625,11 @@ sub noun {
     s/^ya$g/yazh/o ||
     1;
 
-    # remove unnecessary accents: if the accented vowel is
-    # the penultimate vowel and the last vowel is not umlauted
-    s/([])(?=[pbtdhcgkfvszmnlr]*[aeiou][pbtdhcgkfvszmnlr]*$)/$unacc{$1}/;
+    if(! $keep_accents) {
+      # remove unnecessary accents: if the accented vowel is
+      # the penultimate vowel and the last vowel is not umlauted
+      s/([])(?=[pbtdhcgkfvszmnlr]*[aeiou][pbtdhcgkfvszmnlr]*$)/$unacc{$1}/;
+    }
   }
 
   return $table;
@@ -653,9 +670,11 @@ sub adj {
         s/om$/m/;
       }
 
-      # remove unnecessary accents: if the accented vowel is
-      # the penultimate vowel and the last vowel is not umlauted
-      s/([])(?=[pbtdhcgkfvszmnlr]*[aeiou][pbtdhcgkfvszmnlr]*$)/$unacc{$1}/;
+      if(! $keep_accents) {
+        # remove unnecessary accents: if the accented vowel is
+        # the penultimate vowel and the last vowel is not umlauted
+        s/([])(?=[pbtdhcgkfvszmnlr]*[aeiou][pbtdhcgkfvszmnlr]*$)/$unacc{$1}/;
+      }
     }
   }
 
@@ -672,7 +691,7 @@ Lingua::Zompist::Verdurian - Inflect Verdurian nouns, verbs, and adjectives
 
 =head1 VERSION
 
-This document refers to version 0.90 of Lingua::Zompist::Verdurian, released
+This document refers to version 0.91 of Lingua::Zompist::Verdurian, released
 on 2002-05-20.
 
 =head1 SYNOPSIS
@@ -708,6 +727,13 @@ or
   $word = classimp('ivrec');    # "classical" imperative
   $word = part('ivrec');        # participles
 
+  # keep "unnecessary" accents or not
+  # Note: "lav\xedsia" is "lavi'sia"
+  $Lingua::Zompist::Verdurian::keep_accents = 1; # default
+  $word = noun("lav\xedsia")->[6]; # lavi'sem
+  $Lingua::Zompist::Verdurian::keep_accents = 0; # previous behaviour
+  $word = noun("lav\xedsia")->[6]; # lavisem
+
 =head1 DESCRIPTION
 
 =head2 Overview
@@ -897,6 +923,26 @@ adjectives, in the case of present participles of verbs of the I<C>
 conjugation), the other forms of the participles may be obtained by calling the
 L<adj|/"adj"> function, if desired.
 
+=head2 $keep_accents
+
+This variable can be accessed via
+C<$Lingua::Zompist::Verdurian::keep_accents> . Setting it to a true
+value causes accents to be retained even when the accented syllable
+would be accented anyway due to its position. Setting it to a false
+value causes such "unnecessary" accents to be deleted. The default value
+of this variable is true.
+
+For example, the accusative plural of I<lavE<iacute>sia>
+(a dance) is I<lavE<iacute>sem> if the value of
+C<$Lingua::Zompist::Verdurian::keep_accents> is true
+(retaining the accent) and I<lavisem> if the value of
+C<$Lingua::Zompist::Verdurian::keep_accents> is false (removing
+the accent since the I<i> is accented anyway due to its being the
+penultimate vowel now).
+
+This variable only affects the declension of nouns and adjectives, not
+verbal conjugations.
+
 =head1 BUGS
 
 This module should handle irregular words correctly. However, if there is a
